MissingSchemaException class

Thrown when trying to instantiate a schema that hasn't been saved.

Implemented types

Constructors

MissingSchemaException(int requested, Iterable<int> available)

Properties

available → Iterable<int>
All known schema versions.
final
hashCode → int
The hash code for this object.
no setterinherited
requested → int
The requested version that doesn't exist.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited