DartScope class

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextLevel → DartScope
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSuperScope(DartScope other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

inner → const DartScope
library → const DartScope
topLevelMember → const DartScope
values → const List<DartScope>