DataClassWriter class

Constructors

DataClassWriter(MoorEntityWithResultSet table, Scope scope)

Properties

columns → List<MoorColumn>
final
hashCode → int
The hash code for this object.
no setterinherited
isInsertable → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Scope
final
serializerType → String
no setter
table → MoorEntityWithResultSet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited