GenerationOptions class

Options that are specific to code-generation.

Constructors

GenerationOptions({int? forSchema, bool nnbd = false, bool writeDataClasses = true, bool writeCompanions = true, bool writeForMoorPackage = false, bool nullAwareTypeConverters = false})
const

Properties

forSchema → int?
Whether we're generating code to verify schema migrations.
final
hashCode → int
The hash code for this object.
no setterinherited
isGeneratingForSchema → bool
Whether, instead of generating the full database code, we're only generating a subset needed for schema verification.
no setter
nnbd → bool
Whether to generate Dart code that supports non-nullable types.
final
nullAwareTypeConverters → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeCompanions → bool
Whether companions should be generated.
final
writeDataClasses → bool
Whether data classes should be generated.
final
writeForMoorPackage → bool
Whether we're generating code for the old moor package instead of the new drift package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
nullableType(String withoutSuffix) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited