ResultSetWriter class

Writes a class holding the result of an sql query into Dart.

Constructors

ResultSetWriter(SqlQuery query, Scope scope)

Properties

hashCode → int
The hash code for this object.
no setterinherited
query → SqlQuery
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Scope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited