TableWriter class

Inheritance

Constructors

TableWriter(MoorTable table, Scope scope)

Properties

buffer ↔ StringBuffer
getter/setter pairoverride-getter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Scope
final
table → MoorTable
final
tableOrView → MoorTable
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
writeAsDslTable() → void
inherited
writeColumnGetter(MoorColumn column, GenerationOptions options, bool isOverride) → void
inherited
writeDataClass() → void
writeGetColumnsOverride() → void
inherited
writeInto() → void
writeMappingMethod(Scope scope) → void
inherited
writeTableInfoClass() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited