UpdateCompanionWriter class

Constructors

UpdateCompanionWriter(MoorTable table, Scope scope)

Properties

columns → List<MoorColumn>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Scope
final
table → MoorTable
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited